@@ -1,36 +1,35 @@
 import datetime
 import os
-import psutil
 import re
 import subprocess
 import time
 
 from copy import deepcopy
 from pathlib import Path
-from unittest.mock import Mock, MagicMock, PropertyMock, patch, mock_open
+from threading import current_thread, Thread
+from unittest.mock import MagicMock, Mock, mock_open, patch, PropertyMock
+
+import psutil
 
 import patroni.psycopg as psycopg
 
 from patroni import global_config
 from patroni.async_executor import CriticalTask
-from patroni.collections import CaseInsensitiveDict, CaseInsensitiveSet
+from patroni.collections import CaseInsensitiveDict
 from patroni.dcs import RemoteMember
-from patroni.exceptions import PostgresConnectionException, PatroniException
-from patroni.postgresql import Postgresql, STATE_REJECT, STATE_NO_RESPONSE
+from patroni.exceptions import PatroniException, PostgresConnectionException
+from patroni.postgresql import Postgresql, STATE_NO_RESPONSE, STATE_REJECT
 from patroni.postgresql.bootstrap import Bootstrap
 from patroni.postgresql.callback_executor import CallbackAction
-from patroni.postgresql.config import get_param_diff, _false_validator
+from patroni.postgresql.config import _false_validator, get_param_diff
 from patroni.postgresql.postmaster import PostmasterProcess
-from patroni.postgresql.validator import (ValidatorFactoryNoType, ValidatorFactoryInvalidType,
-                                          ValidatorFactoryInvalidSpec, ValidatorFactory, InvalidGucValidatorsFile,
-                                          _get_postgres_guc_validators, _read_postgres_gucs_validators_file,
-                                          _load_postgres_gucs_validators, Bool, Integer, Real, Enum, EnumBool, String,
-                                          transform_postgresql_parameter_value)
+from patroni.postgresql.validator import _get_postgres_guc_validators, _load_postgres_gucs_validators, \
+    _read_postgres_gucs_validators_file, Bool, Enum, EnumBool, Integer, InvalidGucValidatorsFile, \
+    Real, String, transform_postgresql_parameter_value, ValidatorFactory, ValidatorFactoryInvalidSpec, \
+    ValidatorFactoryInvalidType, ValidatorFactoryNoType
 from patroni.utils import RetryFailedError
-from threading import Thread, current_thread
 
-from . import (BaseTestPostgresql, MockCursor, MockPostmaster, psycopg_connect, mock_available_gucs,
-               GET_PG_SETTINGS_RESULT)
+from . import BaseTestPostgresql, GET_PG_SETTINGS_RESULT, MockCursor, MockPostmaster, psycopg_connect
 
 mtime_ret = {}
 
@@ -101,7 +100,6 @@ Data page checksum version:           0
 @patch('subprocess.call', Mock(return_value=0))
 @patch('subprocess.check_output', Mock(return_value=b"postgres (PostgreSQL) 12.1"))
 @patch('patroni.psycopg.connect', psycopg_connect)
-@patch.object(Postgresql, 'available_gucs', mock_available_gucs)
 class TestPostgresql(BaseTestPostgresql):
 
     @patch('subprocess.call', Mock(return_value=0))
@@ -109,7 +107,6 @@ class TestPostgresql(BaseTestPostgresql):
     @patch('patroni.postgresql.CallbackExecutor', Mock())
     @patch.object(Postgresql, 'get_major_version', Mock(return_value=140000))
     @patch.object(Postgresql, 'is_running', Mock(return_value=True))
-    @patch.object(Postgresql, 'available_gucs', mock_available_gucs)
     def setUp(self):
         super(TestPostgresql, self).setUp()
         self.p.config.write_postgresql_conf()
@@ -274,7 +271,7 @@ class TestPostgresql(BaseTestPostgresql):
             self.assertEqual(self.p.checkpoint({'user': 'postgres'}), 'is_in_recovery=true')
         with patch.object(MockCursor, 'execute', Mock(return_value=None)):
             self.assertIsNone(self.p.checkpoint())
-        self.assertEqual(self.p.checkpoint(timeout=10), 'not accessible or not healthy')
+        self.assertEqual(self.p.checkpoint(timeout=10), 'not accessible or not healty')
 
     @patch('patroni.postgresql.config.mtime', mock_mtime)
     @patch('patroni.postgresql.config.ConfigHandler._get_pg_settings')
@@ -367,7 +364,6 @@ class TestPostgresql(BaseTestPostgresql):
 
     @patch.object(Postgresql, 'is_running', Mock(return_value=False))
     @patch.object(Postgresql, 'start', Mock())
-    @patch.object(Postgresql, 'major_version', PropertyMock(return_value=170000))
     def test_follow(self):
         self.p.call_nowait(CallbackAction.ON_START)
         m = RemoteMember('1', {'restore_command': '2', 'primary_slot_name': 'foo', 'conn_kwargs': {'host': 'foo,bar'}})
@@ -915,12 +911,11 @@ class TestPostgresql(BaseTestPostgresql):
         not_none_values = (
             ('foo.bar', 'foo', 160003),  # name, value, version
             ("allow_in_place_tablespaces", 'true', 130008),
-            ("restrict_nonsystem_relation_kind", 'view', 160005),
-            ('fork_specific_param', 'no_validation_file', 170001),
+            ("restrict_nonsystem_relation_kind", 'view', 160005)
         )
         for i in not_none_values:
             self.assertIsNotNone(
-                transform_postgresql_parameter_value(i[2], i[0], i[1], mock_available_gucs.return_value)
+                transform_postgresql_parameter_value(i[2], i[0], i[1])
             )
 
         none_values = (
@@ -930,7 +925,7 @@ class TestPostgresql(BaseTestPostgresql):
         )
         for i in none_values:
             self.assertIsNone(
-                transform_postgresql_parameter_value(i[2], i[0], i[1], mock_available_gucs.return_value)
+                transform_postgresql_parameter_value(i[2], i[0], i[1])
             )
             if i[3]:
                 mock_warning.assert_called_once_with(
@@ -1117,8 +1112,7 @@ class TestPostgresql(BaseTestPostgresql):
         file1_attrs = {'is_file.return_value': True, 'is_dir.return_value': False}
         file1_mock = MagicMock(**file1_attrs)
         file1_mock.name = '__init__.py'
-        file2_attrs = {'is_file.return_value': False, 'is_dir.return_value': True,
-                       'iterdir.side_effect': PermissionError(13, 'Permission denied')}
+        file2_attrs = {'is_file.return_value': False, 'is_dir.return_value': True, 'iterdir.return_value': []}
         file2_mock = MagicMock(**file2_attrs)
         file2_mock.name = '__pycache__'
         file3_attrs = {'is_file.return_value': True, 'is_dir.return_value': False}
@@ -1132,11 +1126,9 @@ class TestPostgresql(BaseTestPostgresql):
         dir_mock = MagicMock(**dir_attrs)
         dir_mock.iterdir.return_value = [file1_mock, file2_mock, file3_mock, file4_mock]
         with patch('patroni.postgresql.available_parameters.conf_dir', dir_mock), \
-             patch('patroni.postgresql.available_parameters.logger.debug') as mock_debug, \
              patch('patroni.postgresql.available_parameters.logger.info') as mock_info, \
              patch('patroni.postgresql.validator.logger.warning') as mock_warning:
             _load_postgres_gucs_validators()
-            self.assertEqual(mock_debug.call_args[0][0], "Can't list directory %s: %r")
             mock_info.assert_called_once_with('Ignored a non-YAML file found under `%s` '
                                               'directory: `%s`.', 'available_parameters', file4_mock)
             mock_warning.assert_called_once()
@@ -1159,12 +1151,6 @@ class TestPostgresql2(BaseTestPostgresql):
     def setUp(self):
         super(TestPostgresql2, self).setUp()
 
-    @patch('subprocess.check_output', Mock(return_value='\n'.join(mock_available_gucs.return_value).encode('utf-8')))
-    def test_available_gucs(self):
-        gucs = self.p.available_gucs
-        self.assertIsInstance(gucs, CaseInsensitiveSet)
-        self.assertEqual(gucs, mock_available_gucs.return_value)
-
     def test_cluster_info_query(self):
         self.assertIn('diff(pg_catalog.pg_current_wal_flush_lsn(', self.p.cluster_info_query)
         self.p._major_version = 90600
@@ -1180,28 +1166,5 @@ class TestPostgresql2(BaseTestPostgresql):
         self.p.config.load_current_server_parameters()
         self.assertTrue(all(self.p.config._server_parameters[name] == value for name, value in keep_values.items()))
         self.assertEqual(dict(self.p.config._recovery_params),
-                         {'primary_conninfo': {'host': 'a', 'port': '5433', 'passfile': '/blabla', 'sslmode': 'prefer',
-                          'gssencmode': 'prefer', 'channel_binding': 'prefer', 'sslnegotiation': 'postgres'}})
-
-    def test_format_dsn(self):
-        params = {'host': '1', 'port': 2, 'target_session_attrs': 'read-write', 'gssencmode': 'prefer',
-                  'channel_binding': 'prefer', 'sslpassword': 'pwd', 'sslcrldir': '/', 'sslnegotiation': 'postgres'}
-        self.p._major_version = 90600
-        self.assertEqual(self.p.config.format_dsn(params), 'host=1 port=2')
-        self.p._major_version = 100000
-        self.assertEqual(self.p.config.format_dsn(params), 'host=1 port=2 target_session_attrs=read-write')
-        self.p._major_version = 120000
-        self.assertEqual(self.p.config.format_dsn(params),
-                         'host=1 port=2 gssencmode=prefer target_session_attrs=read-write')
-        self.p._major_version = 130000
-        self.assertEqual(self.p.config.format_dsn(params),
-                         'host=1 port=2 sslpassword=pwd gssencmode=prefer '
-                         'channel_binding=prefer target_session_attrs=read-write')
-        self.p._major_version = 140000
-        self.assertEqual(self.p.config.format_dsn(params),
-                         'host=1 port=2 sslpassword=pwd sslcrldir=/ gssencmode=prefer '
-                         'channel_binding=prefer target_session_attrs=read-write')
-        self.p._major_version = 170000
-        self.assertEqual(self.p.config.format_dsn(params),
-                         'host=1 port=2 sslpassword=pwd sslcrldir=/ gssencmode=prefer channel_binding=prefer '
-                         'target_session_attrs=read-write sslnegotiation=postgres')
+                         {'primary_conninfo': {'host': 'a', 'port': '5433', 'passfile': '/blabla',
+                          'gssencmode': 'prefer', 'sslmode': 'prefer', 'channel_binding': 'prefer'}})
