@@ -1,8 +1,9 @@
 import os
 import unittest
+
 from threading import Thread
 from unittest import mock
-from unittest.mock import Mock, PropertyMock, patch
+from unittest.mock import Mock, patch, PropertyMock
 
 from patroni import global_config, psycopg
 from patroni.dcs import Cluster, ClusterConfig, Member, Status, SyncState
@@ -11,7 +12,7 @@ from patroni.postgresql.misc import fsync_dir
 from patroni.postgresql.slots import SlotsAdvanceThread, SlotsHandler
 from patroni.tags import Tags
 
-from . import BaseTestPostgresql, psycopg_connect, MockCursor
+from . import BaseTestPostgresql, MockCursor, psycopg_connect
 
 
 class TestTags(Tags):
@@ -37,7 +38,7 @@ class TestSlotsHandler(BaseTestPostgresql):
         self.s = self.p.slots_handler
         self.p.start()
         config = ClusterConfig(1, {'slots': {'ls': {'database': 'a', 'plugin': 'b'}, 'ls2': None}}, 1)
-        self.cluster = Cluster(True, config, self.leader, Status(0, {'ls': 12345, 'ls2': 12345}),
+        self.cluster = Cluster(True, config, self.leader, Status(0, {'ls': 12345, 'ls2': 12345}, []),
                                [self.me, self.other, self.leadermem], None, SyncState.empty(), None, None)
         global_config.update(self.cluster)
         self.tags = TestTags()
@@ -46,7 +47,7 @@ class TestSlotsHandler(BaseTestPostgresql):
         config = ClusterConfig(1, {'slots': {'test_3': {'database': 'a', 'plugin': 'b'},
                                              'A': 0, 'ls': 0, 'b': {'type': 'logical', 'plugin': '1'}},
                                    'ignore_slots': [{'name': 'blabla'}]}, 1)
-        cluster = Cluster(True, config, self.leader, Status(0, {'test_3': 10}),
+        cluster = Cluster(True, config, self.leader, Status(0, {'test_3': 10}, []),
                           [self.me, self.other, self.leadermem], None, SyncState.empty(), None, None)
         global_config.update(cluster)
         with mock.patch('patroni.postgresql.Postgresql._query', Mock(side_effect=psycopg.OperationalError)):
@@ -88,7 +89,7 @@ class TestSlotsHandler(BaseTestPostgresql):
             'state': 'running', 'conn_url': 'postgres://replicator:rep-pass@127.0.0.1:5436/postgres',
             'tags': {'replicatefrom': 'postgresql0'}
         })
-        cluster = Cluster(True, config, self.leader, Status(0, {'ls': 10}),
+        cluster = Cluster(True, config, self.leader, Status(0, {'ls': 10}, []),
                           [self.me, self.other, self.leadermem, cascading_replica], None, SyncState.empty(), None, None)
         self.p.set_role('replica')
         with patch.object(Postgresql, '_query') as mock_query, \
@@ -109,34 +110,37 @@ class TestSlotsHandler(BaseTestPostgresql):
             self.p.reset_cluster_info_state(None)
             mock_query.return_value = [(
                 1, 0, 0, 0, 0, 0, 0, 0, 0, None, None,
-                [{"slot_name": "ls", "type": "logical", "datoid": 5, "plugin": "b", "xmin": 105,
+                [{"slot_name": "ls", "type": "logical", "datoid": 5, "plugin": "b",
                   "confirmed_flush_lsn": 12345, "catalog_xmin": 105, "restart_lsn": 12344},
-                 {"slot_name": "blabla", "type": "physical", "datoid": None, "plugin": None, "xmin": 105,
+                 {"slot_name": "blabla", "type": "physical", "datoid": None, "plugin": None,
                   "confirmed_flush_lsn": None, "catalog_xmin": 105, "restart_lsn": 12344}])]
-            self.assertEqual(self.p.slots(), {'ls': 12345, 'blabla': 12344})
+            self.assertEqual(self.p.slots(), {'ls': 12345, 'blabla': 12344, 'postgresql0': 0})
 
             self.p.reset_cluster_info_state(None)
             mock_query.return_value = [(
                 1, 0, 0, 0, 0, 0, 0, 0, 0, None, None,
-                [{"slot_name": "ls", "type": "logical", "datoid": 6, "plugin": "b", "xmin": 105,
+                [{"slot_name": "ls", "type": "logical", "datoid": 6, "plugin": "b",
                   "confirmed_flush_lsn": 12345, "catalog_xmin": 105}])]
-            self.assertEqual(self.p.slots(), {})
+            self.assertEqual(self.p.slots(), {'postgresql0': 0})
 
     def test_nostream_slot_processing(self):
         config = ClusterConfig(
             1, {'slots': {'foo': {'type': 'logical', 'database': 'a', 'plugin': 'b'}, 'bar': {'type': 'physical'}}}, 1)
         nostream_node = Member(0, 'test-2', 28, {
             'state': 'running', 'conn_url': 'postgres://replicator:rep-pass@127.0.0.1:5436/postgres',
-            'tags': {'nostream': 'True'}
+            'tags': {'nostream': 'True'},
+            'xlog_location': 10,
         })
         cascade_node = Member(0, 'test-3', 28, {
             'state': 'running', 'conn_url': 'postgres://replicator:rep-pass@127.0.0.1:5436/postgres',
-            'tags': {'replicatefrom': 'test-2'}
+            'tags': {'replicatefrom': 'test-2'},
+            'xlog_location': 98
         })
         stream_node = Member(0, 'test-4', 28, {
-            'state': 'running', 'conn_url': 'postgres://replicator:rep-pass@127.0.0.1:5436/postgres'})
+            'state': 'running', 'conn_url': 'postgres://replicator:rep-pass@127.0.0.1:5436/postgres',
+            'xlog_location': 99})
         cluster = Cluster(
-            True, config, self.leader, Status.empty(),
+            True, config, self.leader, Status(100, {'leader': 99, 'test_2': 98, 'test_3': 97, 'test_4': 98}, []),
             [self.leadermem, nostream_node, cascade_node, stream_node], None, SyncState.empty(), None, None)
         global_config.update(cluster)
 
@@ -146,8 +150,8 @@ class TestSlotsHandler(BaseTestPostgresql):
             cluster._get_permanent_slots(self.p, self.leadermem, 'primary'),
             {'foo': {'type': 'logical', 'database': 'a', 'plugin': 'b'}, 'bar': {'type': 'physical'}})
         self.assertEqual(
-            cluster._get_members_slots(self.p.name, 'primary'),
-            {'test_4': {'type': 'physical', 'expected_active': True}})
+            cluster._get_members_slots(self.p.name, 'primary', False, True),
+            {'test_3': {'type': 'physical', 'lsn': 98}, 'test_4': {'type': 'physical', 'lsn': 98}})
 
         # nostream node must not have slot on primary
         self.p.name = nostream_node.name
@@ -161,8 +165,10 @@ class TestSlotsHandler(BaseTestPostgresql):
 
         # check cascade member-slot existence on nostream node
         self.assertEqual(
-            cluster._get_members_slots(nostream_node.name, 'replica'),
-            {'test_3': {'type': 'physical', 'expected_active': True}})
+            cluster._get_members_slots(nostream_node.name, 'replica', False, True),
+            {'leader': {'type': 'physical', 'lsn': 99},
+             'test_3': {'type': 'physical', 'lsn': 98},
+             'test_4': {'type': 'physical', 'lsn': 98}})
 
         # cascade also does not entitled to have logical slot on itself ...
         self.p.name = cascade_node.name
@@ -216,8 +222,7 @@ class TestSlotsHandler(BaseTestPostgresql):
         self.cluster.status.slots['ls'] = 12346
         with patch.object(SlotsHandler, 'check_logical_slots_readiness', Mock(return_value=False)):
             self.assertEqual(self.s.sync_replication_slots(self.cluster, self.tags), [])
-        with patch.object(SlotsHandler, '_query', Mock(return_value=[('ls', 'logical', 1, 499, 'b',
-                                                                      'a', 5, 100, 500)])), \
+        with patch.object(SlotsHandler, '_query', Mock(return_value=[('ls', 'logical', 499, 'b', 'a', 5, 100, 500)])), \
                 patch.object(MockCursor, 'execute', Mock(side_effect=psycopg.OperationalError)), \
                 patch.object(SlotsAdvanceThread, 'schedule', Mock(return_value=(True, ['ls']))), \
                 patch.object(psycopg.OperationalError, 'diag') as mock_diag:
@@ -288,63 +293,18 @@ class TestSlotsHandler(BaseTestPostgresql):
             self.s.schedule_advance_slots({'foo': {'bar': 100}})
             self.s._advance.sync_slots()
 
-    def test_advance_physical_primary(self):
-        self.p.name = self.me.name
-        config = ClusterConfig(1, {'slots': {'test_1': {'type': 'physical'}}}, 1)
-        cluster = Cluster(True, config, self.leader, Status(0, {}),
-                          [self.me, self.other, self.leadermem], None, SyncState.empty(), None, None)
-        self.other.data['xlog_location'] = 12346
-        global_config.update(cluster)
-
-        # Should advance permanent physical slot on the primary for a node that is cascading from the other node
-        with patch.object(SlotsHandler, '_query', Mock(side_effect=[[('test_1', 'physical', None, 12345, None, None,
-                                                                      None, None, None)], Exception])) as mock_query, \
-                patch('patroni.postgresql.slots.logger.error') as mock_error:
-            self.s.sync_replication_slots(cluster, self.tags)
-            self.assertEqual(mock_query.call_args[0],
-                             ("SELECT pg_catalog.pg_replication_slot_advance(%s, %s)", "test_1", '0/303A'))
-            self.assertEqual(mock_error.call_args[0][0],
-                             "Error while advancing replication slot %s to position '%s': %r")
-
-        # Should drop permanent physical slot on the primary for a node
-        # that is cascading from the other node if given slot has xmin set
-        with patch.object(SlotsHandler, '_query', Mock(side_effect=[[('test_1', 'physical', 1, 12345, None, None,
-                                                                      None, None, None)], Exception])) as mock_query:
-            self.s.sync_replication_slots(cluster, self.tags)
-            self.assertTrue(mock_query.call_args[0][0].startswith('WITH slots AS (SELECT slot_name, active'))
-
     @patch.object(Postgresql, 'is_primary', Mock(return_value=False))
-    @patch.object(Postgresql, 'role', PropertyMock(return_value='replica'))
     def test_advance_physical_slots(self):
-        config = ClusterConfig(1, {'slots': {'blabla': {'type': 'physical'}}}, 1)
-        cluster = Cluster(True, config, self.leader, Status(0, {'blabla': 12346}),
+        config = ClusterConfig(1, {'slots': {'blabla': {'type': 'physical'}, 'leader': None}}, 1)
+        cluster = Cluster(True, config, self.leader, Status(0, {'blabla': 12346}, []),
                           [self.me, self.other, self.leadermem], None, SyncState.empty(), None, None)
         global_config.update(cluster)
         self.s.sync_replication_slots(cluster, self.tags)
-        with patch.object(SlotsHandler, '_query', Mock(side_effect=[[('blabla', 'physical', None, 12345, None, None,
-                                                                      None, None, None)], Exception])) as mock_query, \
+        with patch.object(SlotsHandler, '_query', Mock(side_effect=[[('blabla', 'physical', 12345, None, None, None,
+                                                                      None, None)], Exception])) as mock_query, \
                 patch('patroni.postgresql.slots.logger.error') as mock_error:
             self.s.sync_replication_slots(cluster, self.tags)
             self.assertEqual(mock_query.call_args[0],
                              ("SELECT pg_catalog.pg_replication_slot_advance(%s, %s)", "blabla", '0/303A'))
             self.assertEqual(mock_error.call_args[0][0],
                              "Error while advancing replication slot %s to position '%s': %r")
-
-        with patch.object(SlotsHandler, '_query', Mock(side_effect=[[('blabla', 'physical', 1, 12345, None, None,
-                                                                      None, None, None)], Exception])), \
-                patch.object(SlotsHandler, 'drop_replication_slot', Mock(return_value=(False, True))):
-            self.s._schedule_load_slots = True
-            self.s.sync_replication_slots(cluster, self.tags)
-
-        with patch.object(SlotsHandler, '_query', Mock(side_effect=[[('blabla', 'physical', 1, 12345, None, None,
-                                                                      None, None, None)], Exception])), \
-                patch.object(SlotsHandler, 'drop_replication_slot', Mock(return_value=(True, False))), \
-                patch('patroni.postgresql.slots.logger.warning') as mock_warning:
-            self.s.sync_replication_slots(cluster, self.tags)
-            self.assertEqual(mock_warning.call_args_list[-1][0],
-                             ("Unable to drop replication slot '%s', slot is active", 'blabla'))
-
-        with patch.object(SlotsHandler, '_query', Mock(side_effect=[[('blabla', 'physical', 1, 12345, None, None,
-                                                                      None, None, None)], Exception])), \
-                patch.object(SlotsHandler, 'drop_replication_slot', Mock(return_value=(False, False))):
-            self.s.sync_replication_slots(cluster, self.tags)
